{% extends "doi_site/organisation_wrapper.html" %} {% block content %}
<div>
	<h1>Notes for Users</h1>

	<h2>Share Point Documents</h2>
	{% if roles %}
	<p>
		<a
			href={{ roles }}>
			Roles and Responsibilities for minting DOIs within the {{ organisation_name }} prefix</a>
	</p>
	{% endif %}
	{% if notes %}
	<p>
		<a
			href={{ notes }}>
			Notes for {{ organisation_name }} Issuers</a>
	</p>
	{% endif %}

	<h2>Endpoints</h2>
	<ul>
		<li>{{ request.get_host }}{% url 'doi_view' %}</li>
		<li>{{ request.get_host }}{% url 'metadata_post' %}</li>
		<li>{{ request.get_host }}{% url 'media_view' %}</li>
	</ul>

</div>

{% endblock %}
