/** Add css rules here for your application. */

#doi_body {
	margin-left: auto;
	margin-right: auto;
	width: 70%;
	font-size: 0.8em;
	min-width: 1200px;
}

#doi_header {
	color: white;
	padding: 5pt;
	background: #224488;
}

#testinfo {
	padding: 5pt;
	color: white;
	font-family: sans-serif;
	font-size: medium;
	background-color: red !important;
	clear: both;
	font-weight: bold;
	text-align: center;
}

table#sub_domains {
	width: 80%;
	border: 1px solid black;
	background-color: #fff;
}

table#sub_domains tr {
	border: 1px solid black;
}

table#sub_domains th {
	border: 1px solid black;
	background-color: #eee;
}

table#sub_domains td {
	border: 1px solid black;
}

/* Navigation */
#mainNavigation { 
    overflow: hidden;
    background-color: #fff;
    width: 100%;
    border-left: 1px solid #DADCE0;
    margin-top: 2em;
}

#mainNavUL {    
    margin: 0;
    padding: 0;
    text-align: center;
}

#mainNavUL li {
    float: left;
    border-top: 1px solid #DADCE0;
    border-right: 1px solid #DADCE0;
    padding-top: 0.5em;
    padding-bottom: 0.5em;
    padding-left: 2.5em;
    padding-right: 2.5em;
    list-style-type: none;  
}

#mainNavUL li a {    
    text-decoration: none;
    font-weight: bold;
    color: #333;
}

/* content */
#mainContent {
    background-color: #F8F9FA;
    border: 1px solid #DADCE0;
    padding: 15px;
}
