html {
    background: none repeat scroll 0 0 transparent;
    height: 100%;
}

img{
    border: none;
    margin: 0;
    border: 0;
}   

/* body */
body {
    background: #efc643 url('../../images/stfc/bgUr.png') top left repeat-x;
    font-family:  verdana, arial, sans-serif;
    color: #404040;
    font-size: 0.8em;
    padding: 0;
    margin: 0;
    min-width: 1200px;
}


/* 'widths' sub menu */
#layoutdims {
    clear:both;
    background:#eee;
    border-top:4px solid #000;
    margin:0;
    padding:6px 15px !important;
    text-align:right;
}

/* column container */
.colmask {
    position:relative;      /* This fixes the IE7 overflow hidden bug and stops the layout jumping out of place */
    clear:both;
    float:left;
    width:100%;             /* width of whole page */
    overflow:hidden;        /* This chops off any overhanging divs */
}

/* 3 column settings */
.layout {
    /* background:#ff9; */      /* Right column background colour */    
}

.layout .colmid {
    float:left;
    width:200%;
    margin-left:-190px;     /* Width of right column */
    position:relative;
    right:100%;
    background:#fff;        /* Centre column background colour */
}

.layout .colleft {
    float:left;
    width:100%;
    margin-left:-50%;
    position:relative;
    left:380px;             /* Left column width + right column width */
    /* background:#FFD8B7; */       /* Left column background colour */
    border-right: 1px solid #ccc;
}

.layout .colCenterWrap {
    float:left;
    width:50%;
    position:relative;
    right:190px;            /* Width of left column */
    padding-bottom:1em;     /* Centre column bottom padding. Leave it out if it's zero */
}

.layout .colCenter {
    margin:0 215px;         /* Centre column side padding:
                            Left padding = left column width + centre column left padding width
                            Right padding = right column width + centre column right padding width */
    position:relative;
    left:200%;
    overflow:hidden;
}

.layout .colLeft {
    float:left;
    float:right;            /* This overrides the float:left above */
    width:190px;            /* Width of left column content (left column width minus left and right padding) */
    position:relative;
    right:0px;          /* Width of the left-hand side padding on the left column */
}

.layout .colRight {
    float:left;
    float:right;            /* This overrides the float:left above */
    width:190px;            /* Width of right column content (right column width minus left and right padding) */
    margin-right:0px;   /* Width of right column right-hand padding + left column left and right padding */
    position:relative;
    left:50%;
    border-left: 1px solid #ccc;
}


/* 2 column left menu settings */
.leftmenu {
    /* background:#FFD8B7; */
}

.leftmenu .colright {
    float:left;
    width:200%;
    position:relative;
    left:190px;
    background:#fff;
    border-left: 1px solid #CCCCCC;
}

.leftmenu .col1wrap {
    float:right;
    width:50%;
    position:relative;
    right:200px;
    padding-bottom:1em;
}

.leftmenu .col1 {
    margin: 0 15px 0 224px;
    position: relative;
    right: 100%;
    overflow: hidden;    
}

.leftmenu .col2 {
    float: left;
    width: 190px;
    position: relative;
    right: 191px;
    border-right: 1px solid #ccc;
}





/* footer  */
#footer {
    clear: both;
    background-color: #0e2b52;
    color: #fff;
    height: 25px;
    padding-left: 15px;
    padding-top: 10px;
}

#footerLeft {
    float: left;
}

#footerRight {
    margin-top: -4px;
    font-size: 90%;
    width: 200px;
    padding-right: 15px;
    float: right;
    text-align: right;
}

.footerLinks {
    list-style-type: none;
    padding: 0;
    margin: 0;
    width: 100%;
}

.footerLinks li  {
    list-style-type: none;
    float: left;
    margin-right: 1em;
}

.footerLinks li a {
    color: #FFFFFF;
    display: block;
    font-size: 90%;
    text-decoration: none;
}

#footerBase {   
    margin: 0 30px;
    padding-bottom: 30px;
    color: #666666;
    text-align: center;
}


.printOnly {
    display:none;    
}

/* custom */
#containerWrapper {
    margin: 30px;
    border-radius: 45px 0 0 0;
    box-shadow: 4px 0 12px #555555;
    padding: 0;
    background-color: #fff;
}


.oneColumnLayout {
    padding: 0 30px
}



/* links */
a:link {
    color: #0000FF;
    text-decoration: none;
}

a:visited {
    color: #800080;
    text-decoration: none;
}

a:visited:active {
    color: #FF0000;
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

a:link:hover {
    text-decoration: none;
}

a:active {
    text-decoration: none;
}

a.exLk:link {   
    background: url("../../images/stfc/exlink.gif") no-repeat center right transparent;    
    padding-right: 15px;
    text-decoration: none;
}



/* header */
#headerWrapper {
    position: relative;
    height: 118px;
}

#headerStart{
    float: left;
    overflow: hidden;
    background: url("../../images/stfc/headerBgStart.png") no-repeat scroll left top transparent;
    border-radius: 45px 0 0 0;
    padding: 0;
}

#headerMiddle{
    float: left;
    background: url("../../images/stfc/headerBgRepeat.png") repeat-x scroll left top transparent;
    position: absolute;
    top:0;
    height: 118px;
    left: 350px;
    right: 3px;
}

#headerEnd{
    float: right;
    background: url("../../images/stfc/headerBgEnd.png") no-repeat scroll right top transparent;
    width: 3px;
    height: 118px;
}

#mainLogo {
    margin: 15px 20px 33px 25px;
}


#siteName {
    float: right;
    color: #fff;
    margin: 25px 50px 0 0;
}

.siteName {
    font-size: 3em;
    margin: 0;
    text-align: center;
}

.siteStrapline {
    margin-top: 0;   
}

.siteName a:link{
    color: #fff;
}

.siteName a:visited{
    color: #fff;
}

.siteName a:hover {
    color: #fff;
}

.siteName a:active {
    color: #fff;
} 


#printLogo {
    display: none;
    visibility: hidden;
}

/* Navigation */
#mainNavigation { 
    overflow: hidden;
    border-bottom: 1px solid #000;
    background-color: #fff;
    width: 100%;
    /* override doi.css */    
    border-left: 0px;
    margin-top: 0em;
}

#mainNavUL {    
    margin: 0;
    padding: 0;
    text-align: center;
}

#mainNavUL li {
    float: left;
    border-right: 1px solid #999;
    padding-top: 0.5em;
    padding-bottom: 0.5em;
    padding-left: 2.75em;
    padding-right: 2.75em;
    list-style-type: none;  
    /* override doi.css */    
    border-top: 0px;
}

#mainNavUL li a {    
    text-decoration: none;
    font-weight: bold;
    color: #333;
}

.subMenu ul li {
    border-bottom: 1px solid #BEBEBE;   
    list-style-type: none;
    margin: 0;
    padding: 5px;
}

.subMenuFirstLi {
    margin-top: 25px;
    border-top: 1px solid #BEBEBE;  
}

.subMenuSeparator {
    background-color: #ccc;
    font-weight: bold;      
}


.subMenu ul li a{
    color: #333333;    
    font-size: 1em;
    padding-bottom: 0.5em;
    padding-top: 0.5em;
}   

#navLeftSideBlock {
    margin: 0;
    padding: 0;
}   

#navLeftSideBlock ul, .navUserBlock ul{
    list-style-type: none;
    margin: 0;
    padding: 0;
}

.navSection {
    margin-bottom: 15px;
}

.navSection ul li{
    margin: 5px 0;
}


#loginPanel {
    margin: 10px;
}

.loginText {
    margin-bottom: 10px;
    font-size: 11px;
}

#userPanel {
    color: #0E2B52;
    margin-top: 30px;
    margin-left: 5px;
}


/* sidebar right */
#sidebar-right {    
    padding: 5px 8px 20px 8px;  
}


/* content */
#mainContent {
    background-color: #F8F9FA;
    border: 1px solid #DADCE0;
    margin: 1em 0;
    padding: 15px;
}


/* forms */
form {
    margin-bottom: .5em;
}

input, textarea, select, textfield {
    font: 11px/160% verdana, arial, sans-serif !important;  
    padding: 1px 3px;
}



.searchForm {
    background-color: #F8F9FA;
    border: 1px solid #DADCE0;
    margin-top: .5em;
    margin-bottom: 1em;
    margin-left: .5em;
    margin-right: .5em;
}

fieldset {
    border: solid #DADCE0 1px;
    background-color: #F8F9FA;
    margin: 1em 0 0 0;
    padding : 4px 7px 9px 7px\9; /* IE8 and below */
}

#search input.form-submit:hover,
#search input.form-submit:focus,
#search input.form-text:hover,
#search input.form-text:focus,
#user-login-form input.form-text:hover,
#user-login-form input.form-text:focus,
#user-login-form input.form-submit:hover,
#user-login-form input.form-submit:focus  {
    background-color: #fff;
    color: #485F7E;
    border-color: #B7C7E2;
}


/* table */
/*
table {
    margin: 0.5em 0 1em;
    width: 100%;
}
*/

table {
    margin: 0;
}

thead th {
    border: 1px solid #A8A8A8;
    color: #333333;
    font-size: 90%;
    font-weight: bold;
    padding: 4px 5px 0;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.7);
}
tr.even, tr.odd {
    border-color: #DADCE0;
}
tr.even {
    background-color: #FBFCFE;
}
tr.odd {
    background-color: #FFFFFF;
}
td.active {
    background: none repeat scroll 0 0 #E4ECF5;
}
td {
    padding: 3px;
}
td.menu-disabled {
    background-color: #E5E5E5;
}


hr {
    margin: 0;
    padding: 0;
    border: none;
    height: 1px;
    background: #ccc;
}


/* search result view */
.result hr {
    margin-top: 5px;
}

.resultCheckbox {
    vertical-align: top;
    width: 2em;
}

.result {
    vertical-align: top;
}

.results-paginator-toolbar, .standard-toolbar {    
    font-weight: normal;
}

.standard-toolbar {
    padding: 5px 15px;
}


.top-margin-15px {
    margin-top: 15px;
}

.showing {
    line-height: 2em;
}

.top-standard-toolbar {
    margin-bottom: 15px;    
}


div.facet-values-panel {
    overflow-y: auto;
    max-height: 17em;
    border: 1px solid #ccc;
}

/*
  The Terms facet can have *thousands* of values; IE8 doesn't like that;
  so we need to handle it differently, by setting a fixed height.
*/
div.facet-terms-values-panel {
    overflow-y: auto;
    height: 17em;
    border: 1px solid #ccc;
}

div.facet-values-panel div, div.facet-terms-values-panel div {
      text-indent: -10px;
      margin-left: 13px;
}


/* override primefaes widgets */
.ui-widget-header a {
    /* color: color: #003567; */
}

.ui-toolbar{
    font-family: verdana, arial, sans-serif;
    font-size: 12px;
}

.expression-label {
    min-width: 10em;
    max-width: 10em;
    vertical-align: top;
}

.full-display-title { /* title column in full-display's panelGrids */
    width: 10em;
}

.full-display td { /* main details panelGrid in full-display */
    vertical-align: top;
}

.admin-details td { /* admin details panelGrid in full-display */
    line-height: 1em;
}

.contribsScrollPanel {
    max-height: 17em;
    border: 0px;
    overflow: auto;
}

.bottom-toolbar {
    margin-top: 30px;
}

.top-toolbar {
    margin-bottom: 30px;
}


/* local-file / remote-file used for manifestation download links.
   local-file may cover both cases in some places.
*/
a.local-file[href $='.pdf'] {
    display: inline-block;
    line-height: 18px; /* check your icon height */
    padding-left: 20px;
    background: transparent url(images/pdficon_small.png) center left
        no-repeat;
}

a.remote-file[href $='.pdf'] {
    display: inline-block;
    line-height: 18px; /* check your icon height */
    padding-left: 20px;
    background: transparent url(images/pdficon_small.png) center left
        no-repeat;
}

a.local-file[href $='.htm'],a.remote-file[href $='.htm'],a.local-file[href
    $='.html'],a.remote-file[href $='.html'] {
    background: transparent url(images/stdicon-neu-text-html-16.png) center
        left no-repeat;
}

a.local-file[href $='.doc'],a.remote-file[href $='.doc'],a.local-file[href
    $='.docx'],a.remote-file[href $='.docx'] {
    background: transparent url(images/Word-doc-16x32.png) center left
        no-repeat;
}

a.local-file[href $='.ppt'],a.remote-file[href $='.ppt'] {
    background: transparent url(images/Powerpoint-doc-16x32.png) center left
        no-repeat;
}

a.local-file[href $='.xls'],a.remote-file[href $='.xls'] {
    background: transparent url(images/Powerpoint-doc-16x32.png) center left
        no-repeat;
}

a.local-file {
    display: inline-block;
    line-height: 18px; /* check your icon height */
    padding-left: 20px;
    background: transparent url(images/generic-file-icon.png) center left no-repeat;
    color: green;
}

a.remote-file {
    display: inline-block;
    line-height: 18px; /* check your icon height */
    padding-left: 20px;
    background: transparent url(images/generic-file-icon.png) center left
        no-repeat;
}

/* export views */
.export-options-panel {
    /* panel (table) of checkboxes in export-options page - override default width:100% */
    width: 30em;
}

.export-options-column {
    /* columns of checkboxes in export-options page */
    width: 10em;
}


table.export-table, table.export-table-inner {
    margin: 0 0 0;
}

.disambiguate-odd-work, .export-odd-work {
    background: none repeat scroll 0 0 #DCE6F2;
}

.disambiguate-even-work, .export-even-work {

}

table.export-table td { /* removing padding from outer export table */
    padding: 0px;
}

.export-workid-column { /* workid column in export page */
    width: 5em;
}


.disambig-contrib{
    font-style:italic;
}

.bold{
    font-weight: bold;
}

span.volume {
    /* used to format "Volume <volumeNumber>" */
    /* bold disabled: TRAC #73, #82 */
    /* font-weight: bold; */
}


/* OrgUnit browse/admin filters display */

div.selectFilter {
    float: left;
}

div.inputFilter {
    float: left;
    padding-left: 20px;
}

div.filterButtons {
    float: left;
    clear: left;
}


.topStyle {
    vertical-align: top;
}


/* faces messages */
.errorMessage {    
    color: red;
}

/* User management */
.usersAdminFilterLeft {
    width: 10em;
}

span.contentAdmin, span.sysAdmin {
    font-weight: bold;
    color: red;
}


/*  messages */
.successMessages {
    color: #4F8A10;
    background-color: #DFF2BF;
    border: 1px solid;
    margin: 5px 0px;
    padding:10px;
    background-repeat: no-repeat;
    background-position: 10px center;
}

.errorMessages {
    color: #D8000C;
    background-color: #FFBABA;
    border: 1px solid;
    margin: 5px 0px;
    padding:10px;
    background-repeat: no-repeat;
    background-position: 10px center;
}

.infoMessages {
    color: #00529B;
    background-color: #BDE5F8;
    border: 1px solid;
    margin: 5px 0px;
    padding:10px;
    background-repeat: no-repeat;
    background-position: 10px center;
}


.warningMessages {
    color: #9F6000;
    background-color: #FEEFB3;
    border-bottom: 1px solid #999999;
    margin: 0;
    padding: 10px;
}

#serviceMessage {
    background-color: #BDE5F8;
    background-position: 10px center;
    background-repeat: no-repeat;
    border-bottom: 1px solid;
    color: #00529B;
    margin: 0;
    padding: 10px;
}

/* help and news views */
.help-context {
    cursor: pointer;
    cursor: hand;
}

.newsItem {
    margin: 20px 0;
}

div.newsBody {
    padding-bottom: 20px;
}

.newsItem hr {
    background: #DADCE0;
}


.debug {
    background-color: #F0F8FF;
    color: #0000CC;
    border: 1px solid #DADCE0;
    margin: 1em 0;
    padding: 15px;
}


/* work edit*/
.contrib-no {
    width: 15px;
}

.contrib-intials {
    width: 60px;
}


.contrib-name {
    width: 140px;
}


.contrib-title {
    width: 60px;
}


.contrib-role {
    width: 130px;
}


.contrib-role {
    width: 130px;
}

.contrib-affiliation {
    width: 160px;
}

.contrib-disambiguate {
    width: 155px;
}


.contrib-nav {
    width: 160px;
}


.contrib-initials-input {
    width: 60px;
}

.contrib-name-input {
    width: 140px;
}


.contrib-title-input {
    width: 60px;
}


.contrib-role-input {
    width: 130px;
}


.contrib-affiliation-input {
    width: 160px;
}


.leftMargin5px {
    margin-left: 5px        
}


.buttonWithLeftMargin {
    margin-left: 5px;
}


.ui-button-text {
    padding: 2px 5px !important;
    color: #333 !important;
    font-weight: normal !important;
}

.linkButton {
    padding: 3px 5px;    
    font-weight: normal !important;
    color: #4F4F4F !important;
}


/* saf3+, chrome1+ */
@media screen and (-webkit-min-device-pixel-ratio:0) {
    .linkButton  {
        padding: 3px 5px;
        font-weight: normal !important;
        color: #4F4F4F !important;
    }
}

/* ie8 */
@media \0screen {
    .linkButton  {
        padding: 4px 5px;
        font-weight: normal !important;
        color: #4F4F4F !important;
    }
}


.pfButton {
    padding: 3px 5px;
    font-weight: normal !important;
}


.seriesNumberFieldSeperator {
    margin: 25px 0;
    color: #DADCE0;
    background-color: #DADCE0;
    border: none;
    height: 1px;
}

.orgUnitTypeFilterListBox {
    height: 7em;
}

#disambiguateLinkDiv {
    margin-top: 10px;
    margin-bottom: 20px;
}

table.disambiguate-contributor-table td{
    padding: 2px;
}

.disambiguateColumn_1 {
    width: 20px;
}

.disambiguateColumn_2 {
    width: 75px;
}

.disambiguateColumn_3 {

}

.result hr {
    margin-top: 5px;
}

#userEditForm label {
    display:inline-block;
    width:150px;
}

#filterBlock ul {
    list-style-type: none;
    margin: 0;
    padding: 0;

}

.filterName {
    margin-top: 10px;

}

.filterSection {


}

.clearFilter {
    margin: 5px 0;
}


.clearFilterLabel {
    margin-left: 5px;
}


.deletedEntry {
    font-weight: bold;
    color: red;
}

.seriesSelect {
    width: 640px;
        
}

.clear {
    clear: both;
}


/* work edit form */
.orgUnitBlock {    
    float: left;
    
} 

.organisations {
    margin: 0 20px 0 0;    
}

.departments {
    margin: 0;
}

.divisionsOrGroups{
    margin: 0 20px 0 0;
}

.collaborations{
    margin: 0;
}

.select70Charwidth {
    width: 460px;
}

.select50Charwidth {
    width: 400px;
}

.fieldLabel {
    
}

.fieldLabel label {
    font-weight: bold;
}

.fieldSection {    
    
}

.fieldHelp {
    font-size: 11px;
    margin-bottom: 15px;
}

.fieldSeparator {
    margin: 15px 0;
}

span.required {
    color: red;
    font-size: 11px;    
}


span.recommended {
    color: #006600;
    font-size: 11px;
}


.selectedSeriesInfo {
    display: inline-block;
    border: 1px solid #DADCE0;
    background-color: #fff; 
    padding: 5px;
}

span.selectedSeriesInfoLabel {
    display: inline-block;
    width: 150px;
}

.serialInfo {
    display: inline-block;
    width: 150px;
    margin: 5px 0;
}


.workContrib {
    margin-bottom: 5px;
}

.workStatus {
    margin-bottom: 10px;
        
}

.deleted {
    color: #FF0000;    
}

.submitted {
    color: #FF6600;    
}


.isAdded {
    color: #006600;
}

.isEdited {
    color: #FF0000;
    
}


.lookupTitle {
    margin-top: 10px;    
}

.citations li{
    margin: 15px 0;
    list-style-type: none;
}

.citations {
    padding: 0;
    margin: 0;
}


/* cookie bar css */ 
#cookie-bar {
    background:#0E2B52; 
    height:24px; 
    line-height:24px; 
    color:#eeeeee; 
    text-align:center; 
    padding:10px 0;
}
#cookie-bar.fixed {
    position:fixed; 
    top:0; 
    left:0; 
    width:100%;
}

#cookie-bar p {
    margin:0; 
    padding:0;
}
#cookie-bar a {
    color:#ffffff; 
    display:inline-block; 
    border-radius:3px; 
    text-decoration:none; 
    padding:0 6px; 
    margin-left:8px;
}
#cookie-bar .cb-enable {
    background:#007700;
}

#cookie-bar .cb-enable:hover {
    background:#009900;
}

#cookie-bar .cb-disable {
    background:#990000;
}

#cookie-bar .cb-disable:hover {
    background:#bb0000;
}

#cookie-bar .cb-policy {
    background:#0033bb;
}

#cookie-bar .cb-policy:hover {
    background:#0055dd;
}

table.cookieInfo {
    border-collapse:collapse;
    width: 80%;
}

.cookieInfo table, .cookieInfo th, .cookieInfo td {
    border: 1px solid grey;
}


.cookieInfo ul {    
    padding: 0;
    margin: 0;
}

.cookieInfo li  {
    list-style-type: none;
}



    