{% extends "doi_site/organisation_wrapper.html" %} {% block content %}

<h1>Register new Dataset</h1>
<p>DOI latency: Be aware that it can take up to 24 hours until a DOI update is globally known. New DOIs should be resolvable after about 5 minutes.</p>
<p>DOI:</p>
<p>Url:</p>
<p>XML upload:</p>
<p>Browse</p>
<p>No file selected</p>
<p>Please select an XML file. It must reference a schema located under the following base URL: http://schema.datacite.org/meta/</p>
<p>XML:</p>
<p>SAVE</p>


{% endblock %}
