{% extends "doi_site/organisation_wrapper.html" %} {% block content %}

<h1>DOI Sub-Domains Accessible via this Service</h1>
<table id="sub_domains">
	<tr>
		<th>sub-domain</th>
		<th>name</th>
		<th>contacts</th>
	</tr>

	{% for profile in group_profiles %}
	<tr>
		<td>{{ doi_prefix }}{{ profile.doi_suffix }}</td>
		<td>{{ profile.group }}</td>
		<td>
		{% for user in profile.group.user_set.values %}
			{% if forloop.last %}
				{{user.first_name }} {{ user.last_name }}
			{% else %}
				{{user.first_name }} {{ user.last_name }},
			{% endif %}
		{% endfor %}
		</td>
	</tr>
	{% endfor %}

</table>

{% endblock %}
