{% extends "doi_site/organisation_wrapper.html" %}

{% block content %}
<div>
	<h1>What is this service?</h1>
	<p>
		This service provides a wrapper around the <a
			href="https://mds.datacite.org/" target="_blank">DataCite
			Metadata Store</a> for members of {{organisation_name}}. The DataCite
		Metadata Store is a service for data publishers to mint DOIs and
		register associated metadata. This service requires users to first
		register for an account with a {{organisation_name}} DataCite
		representative <a href="mailto:{{organisation_email}}">{{organisation_email}}</a>
		. Once registered, a user will be able to use their federal id to mint
		DOIs. For information about DataCite and DOIs, see their <a
			href="http://www.datacite.org/faqs" target="_blank">Frequently
			asked questions</a>.
	</p>
	<h1>Who can use this service?</h1>
	<p>This service is aimed at scientific and research data
		publishers.</p>
	<h1>I have datasets and want to mint DOIs! How can I use this
		service?</h1>
	<p>There are two steps. Firstly, you will need to register with our
		service. Please contact a {{organisation_name}} DataCite
		representative who will get in touch with you to discuss your
		eligibility, requirements and responsibilities. If you qualify, they
		will provide you with the necessary information.</p>
	<p>
		Secondly, you will need to use the DataCite <a
			href="https://mds.datacite.org/static/apidoc" target="_blank">application
			programming interface (API)</a> to mint DOIs. It is recommended that you
		integrate minting and updating DOIs with your metadata management
		infrastructure. So if, for example, a URL changes, automatic
		notification will be pushed to our service and the updated URL will be
		used for resolving the DOI.
	</p>
	<h1>How can I contact you?</h1>
	<p>
		To set up an account please contact <a
			href="mailto:{{organisation_email}}">{{organisation_email}}</a>.
	</p>
</div>

{% endblock %}
