{% extends "doi_site/organisation_wrapper.html" %} {% block content %}

<h1>DOIs</h1>

<ul>
{% for doi in dois %}
	<li><a href="{{ handler }}{{ doi }}" target="_blank">{{ doi }}</a></li>
{% endfor %}
</ul>

{% endblock %}
