body {
    font-size: 12px;
}    

#mainNavigation, #footer, #mainLogo, .sidebar-left, .results-paginator-toolbar, .colLeft, .colRight, .col2, .debug {
    display:none;
}

a {
    text-decoration: none;
}

#siteLogo {
    margin-top: 5px;
    margin-left: 5px;
    float: left;
}   

#siteName {
    float: right;
    margin-top: 5px;
    margin-right: 5px;
    text-align: center;
}

#siteName  h1 {
    font-size: 3em;
    margin: 10px;
}

#headerEnd {
    clear: both;
}

.siteStrapline {
    margin-top: 0;
    font-size: 0.8em;
}

#mainContent {
    width: 100%; 
    margin: 0;
    float: none;
}    

#footerBase {
    margin-top: 20px;
    clear: both;
}

#mainForm\:marked {
    width: 100%;
}

.ui-widget {
    font-size: 1em;
    font-weight: normal;
}

a.manifest {
    display: none;
}

table#mainForm\:exprTable, table.full-display {
    margin-top: 10px;
    width: 100%;    
}

#mainForm\:exprTable table, #mainForm\:exprTable th, #mainForm\:exprTable td {
    border: 1px solid grey;
}

.full-display table, .full-display th, .full-display td {
    border: 1px solid grey;
}


.citations {
    margin: 0;
    padding: 0;
}

.citations li {
    list-style-type: none;
    margin: 12px 0;
}




