{% load staticfiles %}

<!DOCTYPE html>
<html lang="en">

<head>
	<title>DOI Minting Service</title>	
	<link rel="stylesheet" type="text/css" href="{% static 'doi_site/css/doi.css' %}" />
	{% block head %}
	{% endblock %}
</head>

<body id="doi_body">
    <div>
		{% block page_header %}
		<div id="doi_header">
			<h1>DOI Minting Service</h1>
			<p>The DOI service for research data</p>
		</div>	
		{% endblock %}

		{% if is_testing %}
		<div id="testinfo">This service is for testing only.</div>
		{% endif %}

		{% block navbar %}
		<div id="mainNavigation">
			<ul id="mainNavUL">
				<li><a href="/">Home</a></li>
				<li><a href="{% url 'domains' %}">DOI Sub-Domains</a></li>
				<li><a href="{% url 'doi_list' %}">DOIs</a></li>			
				<li><a href="{% url 'mint' %}">Mint a DOI</a></li>			
				<li><a href="{% url 'notes' %}">Notes for Users</a></li>			
				<li><a href="https://mds.datacite.org/static/apidoc" target="_blank">API Docs</a> (external page)</li>
				{% if user.is_authenticated %}
					<li>Hello {{ user.first_name }}
					[<a href="{% url 'logout' %}">Logout</a>]</li>
				{% else %}
					<li><a href="{% url 'login' %}">Login</a></li>
				{% endif %}
			</ul>
		</div>
		{% endblock %}

    	<div id="mainContent">
        	{% block content %}{% endblock %}
    	</div>
    	
        {% block footer %}{% endblock %}
    </div>

</body>

</html>
